@@ -12,7 +12,7 @@ import requests
 
 import credentials
 
-__version__ = '1.0'
+__version__ = '1.1'
 
 def pytest_configure(config):
     if not hasattr(config, 'slaveinput'):
@@ -43,9 +43,21 @@ def pytest_unconfigure(config):
 
 
 def pytest_sessionstart(session):
-    if session.config.option.base_url and not session.config.option.collectonly:
+    if session.config.option.base_url and not (session.config.option.skip_url_check or session.config.option.collectonly):
         r = requests.get(session.config.option.base_url, verify=False)
-        assert r.status_code == 200, 'Base URL did not return status code 200. (URL: %s, Response: %s)' % (session.config.option.base_url, r.status_code)
+        assert r.status_code in (200, 401), 'Base URL did not return status code 200 or 401. (URL: %s, Response: %s)' % (session.config.option.base_url, r.status_code)
+
+    # configure session proxies
+    if hasattr(session.config, 'browsermob_session_proxy'):
+        session.config.option.proxy_host = session.config.option.bmp_host
+        session.config.option.proxy_port = session.config.browsermob_session_proxy.port
+
+    if hasattr(session.config, 'zap'):
+        if all([session.config.option.proxy_host, session.config.option.proxy_port]):
+            session.config.zap.core.set_option_proxy_chain_name(session.config.option.proxy_host)
+            session.config.zap.core.set_option_proxy_chain_port(session.config.option.proxy_port)
+        session.config.option.proxy_host = session.config.option.zap_host
+        session.config.option.proxy_port = session.config.option.zap_port
 
 
 def pytest_runtest_setup(item):
@@ -57,10 +69,15 @@ def pytest_runtest_setup(item):
         'network_traffic': []}
     TestSetup.base_url = item.config.option.base_url
 
+    # configure test proxies
+    if hasattr(item.config, 'browsermob_test_proxy'):
+        item.config.option.proxy_host = item.config.option.bmp_host
+        item.config.option.proxy_port = item.config.browsermob_test_proxy.port
+
     # consider this environment sensitive if the base url or any redirection
     # history matches the regular expression
     sensitive = False
-    if TestSetup.base_url:
+    if TestSetup.base_url and not item.config.option.skip_url_check:
         r = requests.get(TestSetup.base_url, verify=False)
         urls = [h.url for h in r.history] + [r.url]
         matches = [re.search(item.config.option.sensitive_url, u) for u in urls]
@@ -158,6 +175,11 @@ def pytest_addoption(parser):
                      default=config.get('DEFAULT', 'baseurl'),
                      metavar='url',
                      help='base url for the application under test.')
+    group._addoption('--skipurlcheck',
+                     action='store_true',
+                     dest='skip_url_check',
+                     default=False,
+                     help='skip the base url and sensitivity checks. (default: %default)')
     group._addoption('--api',
                      action='store',
                      default=config.get('DEFAULT', 'api'),
@@ -200,6 +222,16 @@ def pytest_addoption(parser):
                      dest='firefox_preferences',
                      metavar='str',
                      help='json string of firefox preferences to set (webdriver).')
+    group._addoption('--profilepath',
+                     action='store',
+                     dest='profile_path',
+                     metavar='str',
+                     help='path to the firefox profile to use (webdriver).')
+    group._addoption('--extension',
+                     action='append',
+                     dest='extension_paths',
+                     metavar='str',
+                     help='path to browser extension to install (webdriver).')
     group._addoption('--chromeopts',
                      action='store',
                      dest='chrome_options',
@@ -255,6 +287,16 @@ def pytest_addoption(parser):
                      dest='assume_untrusted',
                      default=False,
                      help='assume that all certificate issuers are untrusted. (default: %default)')
+    group._addoption('--proxyhost',
+                     action='store',
+                     dest='proxy_host',
+                     metavar='str',
+                     help='use a proxy running on this host.')
+    group._addoption('--proxyport',
+                     action='store',
+                     dest='proxy_port',
+                     metavar='int',
+                     help='use a proxy running on this port.')
 
     group = parser.getgroup('safety', 'safety')
     group._addoption('--sensitiveurl',
